# API Reference

## Pipeline

```{autodoc2-summary}
flashscenic.pipeline.run_flashscenic
```

```{autodoc2-object} flashscenic.pipeline.run_flashscenic
```

## Data Download

```{autodoc2-summary}
flashscenic.data.download_data
flashscenic.data.list_available_resources
flashscenic.data.DownloadedResources
```

```{autodoc2-object} flashscenic.data.download_data
```

```{autodoc2-object} flashscenic.data.list_available_resources
```

```{autodoc2-object} flashscenic.data.DownloadedResources
```

## AUCell

```{autodoc2-object} flashscenic.aucell.get_aucell
```

## cisTarget

```{autodoc2-summary}
flashscenic.cistarget.CisTargetPruner
flashscenic.cistarget.compute_recovery_aucs
flashscenic.cistarget.compute_nes
flashscenic.cistarget.prune_single_module
flashscenic.cistarget.MotifAnnotation
flashscenic.cistarget.filter_by_annotations
```

```{autodoc2-object} flashscenic.cistarget.CisTargetPruner
```

```{autodoc2-object} flashscenic.cistarget.compute_recovery_aucs
```

```{autodoc2-object} flashscenic.cistarget.compute_nes
```

```{autodoc2-object} flashscenic.cistarget.prune_single_module
```

```{autodoc2-object} flashscenic.cistarget.MotifAnnotation
```

```{autodoc2-object} flashscenic.cistarget.filter_by_annotations
```

## Module Utilities

```{autodoc2-summary}
flashscenic.modules.select_topk_targets
flashscenic.modules.select_threshold_targets
flashscenic.modules.filter_by_min_targets
flashscenic.modules.filter_by_mapped_fraction
flashscenic.modules.get_target_indices
flashscenic.modules.binarize
flashscenic.modules.to_numpy
```

```{autodoc2-object} flashscenic.modules.select_topk_targets
```

```{autodoc2-object} flashscenic.modules.select_threshold_targets
```

```{autodoc2-object} flashscenic.modules.filter_by_min_targets
```

```{autodoc2-object} flashscenic.modules.filter_by_mapped_fraction
```

```{autodoc2-object} flashscenic.modules.get_target_indices
```

```{autodoc2-object} flashscenic.modules.binarize
```

```{autodoc2-object} flashscenic.modules.to_numpy
```

## Helpers

```{autodoc2-object} flashscenic.regulons_to_adjacency
```
